@@ -12,7 +12,7 @@ int main (int argc, char *argv[])
     QTranslator translator;
     if (settings.value("server").toString()=="godvillegame.com" or (!settings.contains("server") and QLocale::system().name()!="ru_RU"))
     {
-        translator.load("qgodville_en", ".");
+        translator.load("qgodville_en", "/usr/bin/qgodville");
         app.installTranslator(&translator);
     }
 
